@@ -11,7 +11,6 @@ def test_login(user_key):
     u, k = user_key
     runner = CliRunner()
     result = runner.invoke(main.login, [k])
-    print(result.output)
     assert result.exit_code == 0
     assert result.output == f"Authentication successful for user: {u}\n"
 
@@ -20,4 +19,5 @@ def test_login(user_key):
     assert result.output == "Authentication failed: Key format is invalid\n"
     with open(os.path.expanduser("~/.config/tktl/config.json"), "r") as j:
         d = json.load(j)
-    assert d["api-key"] == "FAKEAPIKEY"
+    assert d["api-key"] != "FAKEAPIKEY"
+    assert d["api-key"] == k
