@@ -6,7 +6,7 @@ from pydantic import BaseModel
 
 from tktl.core.clients.http_client import API, interpret_response
 from tktl.core.config import settings
-from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.exceptions import APIClientException
 from tktl.core.managers.auth import AuthConfigManager
 
 
@@ -53,14 +53,12 @@ def test_interpret_response():
     with pytest.raises(APIClientException):
         interpret_response(response, model=BaseModel)
 
-    client = API(api_url="https://jsonplaceholder.typicode.com/todos/1")
+    client = API(api_url="https://my-json-server.typicode.com/typicode/demo/posts/1")
     response = client.get()
 
     class TestModel(BaseModel):
-        userId: int
         id: int
         title: str
-        completed: bool
 
     interpreted = interpret_response(response, TestModel)
     assert interpreted.dict()["id"] == 1
