@@ -2,7 +2,7 @@ import pytest
 from pydantic import UUID4
 
 from tktl.commands.deployments import GetDeployments, GetEndpoints
-from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.exceptions import APIClientException
 from tktl.login import logout
 
 
@@ -17,14 +17,14 @@ def test_get_deployment_commands(logged_in_context):
         None,
         return_all=False,
     )
-    assert len(result) == 2
+    assert len(result) == 1
 
     result = cmd.execute(None, None, None, None, None, None, return_all=True)
-    assert len(result) >= 3
+    assert len(result) >= 5
 
     cmd = GetEndpoints()
     result = cmd.execute(
-        UUID4("582132db-6687-4c87-9907-ffbc8f03fa07"),
+        UUID4("427cae9a-275f-469f-acc0-5478614ec863"),
         None,
         None,
         None,
@@ -33,7 +33,7 @@ def test_get_deployment_commands(logged_in_context):
         None,
         None,
     )
-    assert len(result) == 1
+    assert len(result) == 4
 
     cmd = GetDeployments()
     with pytest.raises(APIClientException):
