@@ -8,8 +8,8 @@ import pytest
 from pydantic import BaseModel
 
 from tktl import Tktl
-from tktl.core.exceptions.exceptions import ValidationException
-from tktl.core.utils import DelayedLoadingFrame
+from tktl.core.exceptions import ValidationException
+from tktl.core.utils import DelayedLoaderX, DelayedLoaderY
 from tktl.registration.validation import (
     get_input_and_output_for_profiling,
     input_pandas_representation,
@@ -212,7 +212,5 @@ def test_delayed_loaded_frame(create_proj):
     assert tktl.endpoints[0].profiling_supported is True
     input_schema = tktl.endpoints[0].input_schema
     output_schema = tktl.endpoints[0].output_schema
-    assert isinstance(input_schema.value, DelayedLoadingFrame)
-    assert isinstance(output_schema.value, DelayedLoadingFrame)
-    assert output_schema.value.is_label is True
-    assert input_schema.value.profile_columns == input_schema.value.columns
+    assert isinstance(input_schema.value, DelayedLoaderX)
+    assert isinstance(output_schema.value, DelayedLoaderY)
