@@ -96,7 +96,6 @@ def test_nan_handling_multi_dim():
     assert schema.__name__ == RestSchemaTypes.ARRAY.value
     sample = numpy.random.randn(2, 3).tolist()
     assert schema.validate([sample])
-    print(schema.schema())
     assert schema.schema()["items"]["items"]["items"]["type"] == "number"
     assert schema.schema()["example"] == [[[None, 1.1, 0.0], [12.1, 1, 3]]]
     with pytest.raises(ValidationError):
@@ -136,4 +135,4 @@ def test_from_dict_or_list_of_dicts():
     assert valid.deserialize() == {"a": 10, "b": 20}
 
     with pytest.raises(ValidationError):
-        print(mapping_model(**{"c": 20, "b": "sdfgasdfg"}))
+        mapping_model(**{"c": 20, "b": "sdfgasdfg"})
