@@ -7,7 +7,8 @@ from tktl.cli.common import (
     validate_project_shared_options,
 )
 from tktl.commands.validate import (
-    validate_all,
+    build_image,
+    get_docker_manager,
     validate_endpoint_sample,
     validate_import,
     validate_integration,
@@ -48,7 +49,11 @@ def validate_import_command(
     path: str, cache: bool, prune: bool, secrets_repository: str
 ) -> None:
     secrets = get_secrets(secrets_repository)
-    validate_import(path=path, cache=cache, prune=prune, secrets=secrets)
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+    validate_import(dm=dm, image=image)
+    if prune:
+        dm.remove_image(image)
 
 
 @validate.command("sample", help="Validate Sample Data on Endpoints")
@@ -63,7 +68,11 @@ def validate_sample_command(
     path: str, cache: bool, prune: bool, secrets_repository: str
 ) -> None:
     secrets = get_secrets(secrets_repository)
-    validate_endpoint_sample(path=path, cache=cache, prune=prune, secrets=secrets)
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+    validate_endpoint_sample(dm=dm, image=image)
+    if prune:
+        dm.remove_image(image)
 
 
 @validate.command("unittest", help="Validate the unittests")
@@ -78,7 +87,11 @@ def validate_unittest_command(
     path: str, cache: bool, prune: bool, secrets_repository: str
 ) -> None:
     secrets = get_secrets(secrets_repository)
-    validate_unittest(path=path, cache=cache, prune=prune, secrets=secrets)
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+    validate_unittest(dm=dm, image=image)
+    if prune:
+        dm.remove_image(image)
 
 
 @validate.command("integration", help="Validate integration")
@@ -99,14 +112,11 @@ def validate_integration_command(
     secrets_repository: str,
 ) -> None:
     secrets = get_secrets(secrets_repository)
-    validate_integration(
-        path=path,
-        cache=cache,
-        prune=prune,
-        timeout=timeout,
-        retries=retries,
-        secrets=secrets,
-    )
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+    validate_integration(dm=dm, image=image, timeout=timeout, retries=retries)
+    if prune:
+        dm.remove_image(image)
 
 
 @validate.command("profiling", help="Validate profiling")
@@ -127,14 +137,13 @@ def validate_profiling_command(
     secrets_repository: str,
 ) -> None:
     secrets = get_secrets(secrets_repository)
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
     validate_profiling(
-        path=path,
-        cache=cache,
-        prune=prune,
-        timeout=timeout,
-        retries=retries,
-        secrets=secrets,
+        dm=dm, image=image, timeout=timeout, retries=retries, prune=prune
     )
+    if prune:
+        dm.remove_image(image)
 
 
 @validate.command("all", help="Validate everything")
@@ -154,12 +163,19 @@ def validate_all_command(
     retries: int,
     secrets_repository: str,
 ) -> None:
+    validate_project_config(path=path)
+
     secrets = get_secrets(secrets_repository)
-    validate_all(
-        path=path,
-        cache=cache,
-        prune=prune,
-        timeout=timeout,
-        retries=retries,
-        secrets=secrets,
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+
+    validate_import(dm=dm, image=image)
+    validate_endpoint_sample(dm=dm, image=image)
+    validate_unittest(dm=dm, image=image)
+    validate_integration(dm=dm, image=image, timeout=timeout, retries=retries)
+    validate_profiling(
+        dm=dm, image=image, timeout=timeout, retries=retries, prune=prune
     )
+
+    if prune:
+        dm.remove_image(image)
