@@ -2,7 +2,7 @@ from tktl import __version__
 from tktl.commands import BaseTaktileApiCommand, CommandBase
 from tktl.core.clients.http_client import interpret_response
 from tktl.core.config import settings
-from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.exceptions import APIClientException
 from tktl.core.loggers import LOG
 from tktl.core.schemas.user import TaktileUser
 from tktl.login import login, logout, set_api_key
