@@ -1,7 +1,6 @@
 from typing import Dict
 
-from tktl.commands.validate import build_image
-from tktl.core.exceptions import MissingDocker
+from tktl.commands.validate import build_image, get_docker_manager
 from tktl.core.loggers import LOG, stream_blocking_logs
 
 
@@ -14,14 +13,9 @@ def run_container(
     color_logs: bool,
     secrets: Dict = None,
 ):
-    try:
-        dm, image = build_image(path, cache=cache, prune=prune, secrets=secrets)
-    except MissingDocker:
-        LOG.log(
-            "Couldn't locate docker, please make sure it is installed, or use the DOCKER_HOST environment variable",
-            color="red",
-        )
-        return
+    dm = get_docker_manager(path=path)
+    image = build_image(dm=dm, path=path, cache=cache, prune=prune, secrets=secrets)
+
     LOG.log("Waiting for service to start...")
     arrow_container, rest_container = dm.run_containers(
         image, detach=True, auth_enabled=auth_enabled
