@@ -1,5 +1,6 @@
 import requests
 
+from tktl import __version__ as tktl_version
 from tktl.core import utils
 from tktl.core.loggers import LOG
 
@@ -7,6 +8,8 @@ from tktl.core.loggers import LOG
 class API:
     DEFAULT_HEADERS = {
         "Accept": "application/json",
+        "User-Agent": f"taktile-cli:{tktl_version}",
+        "Content-Type": "application/json",
     }
 
     def __init__(self, api_url, headers={}):
