@@ -17,7 +17,7 @@ def default_comp(x: Any, y: Any):
 
 
 def branch_comp(x: str, y: str):
-    return x == y or os.path.basename(y) == x
+    return x == y or y == f"refs/heads/{x}"
 
 
 def is_in_sequence_comp(x: Sequence, y: str):
@@ -139,15 +139,6 @@ def get_deployment_from_endpoint_and_branch(
         elif len(branch_filtered) == 1:
             return cast(RepositoryDeployment, branch_filtered[0]["deployment"])
         else:
-            print(
-                [
-                    (
-                        cast(RepositoryDeployment, e["deployment"]).git_ref,
-                        cast(RepositoryDeployment, e["deployment"]).status,
-                    )
-                    for e in endpoint_mapping
-                ]
-            )
             # Impossible to have more than one endpoint in the same branch for the same repo with the same name
             raise TaktileSdkError("This should never, ever happen")
 
