@@ -32,7 +32,7 @@ class Settings(BaseSettings):
     ARROW_BATCH_MB: int = 50
     PARQUET_BATCH_DEFAULT_ROWS_READ: int = int(1e6)
 
-    FUTURE_ENDPOINTS: bool = False
+    FUTURE_ENDPOINTS: bool = True
     TAKTILE_PROFILING_VERSION: Optional[str] = os.environ.get(
         "TAKTILE_PROFILING_VERSION"
     )
