@@ -8,18 +8,6 @@ import pandas as pd  # type: ignore
 from tktl.core import ExtendedEnum
 
 
-class EndpointKinds(str, ExtendedEnum):
-    ADVANCED = "advanced"
-    TYPED = "typed"
-    ARROW = "arrow"
-    PROFILED = "profiled"
-
-
-class ProfileKinds(str, ExtendedEnum):
-    BINARY = "binary"
-    REGRESSION = "regression"
-
-
 class ArrowFormatKinds(str, ExtendedEnum):
     DATAFRAME = "dataframe"
     SERIES = "series"
