@@ -31,35 +31,6 @@ class DockerManager:
         for line in container.logs(stream=True):
             LOG.log(f"> {line.decode()}".strip())
 
-    def _patch_docker_file(
-        self, input_docker_file: str = ".buildfile", output: str = TESTING_DOCKERFILE
-    ):
-        """patch_docker_file
-
-        Remove kaniko related config
-        """
-        with open(os.path.join(self._path, input_docker_file)) as fp:
-            lines = fp.readlines()
-            desired_contents = []
-            for line in lines:
-                if line.startswith("ARG RESOURCE_NAME"):
-                    break
-                desired_contents.append(line)
-
-        with open(os.path.join(self._path, output), "w") as fp:
-            fp.writelines(desired_contents)
-
-    @staticmethod
-    def _is_multi_stage(file_path: str) -> bool:
-        with open(file_path) as fp:
-            lines = fp.readlines()
-            return any(
-                x.startswith(f"FROM {MULTI_STAGE_BUILD_STEP_NAME}") for x in lines
-            )
-
-    def _remove_patched_docker_file(self, file_path: str = TESTING_DOCKERFILE):
-        os.remove(os.path.join(self._path, file_path))
-
     def remove_image(self, image):
         self._client.images.remove(image, force=True)
 
@@ -77,33 +48,18 @@ class DockerManager:
         if not cache:
             LOG.log("Building without Docker cache. This may take some time...")
 
-        # TODO: After phasing out support for non multistage docker files, remove this.
-        if DockerManager._is_multi_stage(dockerfile):
-            LOG.log(
-                f"Multistage dockerfile, building target {MULTI_STAGE_BUILD_STEP_NAME}..."
-            )
-            image, stream = self._client.images.build(
-                path=self._path,
-                dockerfile=dockerfile,
-                tag="taktile-cli-test",
-                nocache=not cache,
-                target=MULTI_STAGE_BUILD_STEP_NAME,
-                buildargs=buildargs,
-                forcerm=True,
-            )
-        else:
-            LOG.log("Patching dockerfile...")
-            self._patch_docker_file(
-                input_docker_file=dockerfile, output=TESTING_DOCKERFILE
-            )
-            image, stream = self._client.images.build(
-                path=self._path,
-                dockerfile=TESTING_DOCKERFILE,
-                tag="taktile-cli-test",
-                nocache=not cache,
-                forcerm=True,
-            )
-            self._remove_patched_docker_file()
+        LOG.log(
+            f"Multistage dockerfile, building target {MULTI_STAGE_BUILD_STEP_NAME}..."
+        )
+        image, stream = self._client.images.build(
+            path=self._path,
+            dockerfile=dockerfile,
+            tag="taktile-cli-test",
+            nocache=not cache,
+            target=MULTI_STAGE_BUILD_STEP_NAME,
+            buildargs=buildargs,
+            forcerm=True,
+        )
 
         for chunk in stream:
             if "stream" in chunk:
