@@ -1,7 +1,8 @@
 import logging
 import os
+from typing import cast
 
-from tktl.core.exceptions.exceptions import validate_config
+from tktl.core.exceptions import validate_config
 from tktl.core.managers.base import BaseConfigManager
 from tktl.core.managers.project import ProjectManager
 
@@ -17,4 +18,4 @@ class LearnerManager(BaseConfigManager):
     @classmethod
     @validate_config
     def get_path(cls, name: str) -> str:
-        return os.path.join(ProjectManager.get_value("saved-models"), name)
+        return os.path.join(cast(str, ProjectManager.get_value("saved-models")), name)
