@@ -3,10 +3,11 @@ from typing import Dict, List, Optional, Union
 
 import certifi
 from pydantic import UUID4, BaseModel, validator
+from taktile_types.enums.instance import ServiceType
 
 from tktl.constants import NON_EXISTING_DEPLOYMENT_DEFAULT_STATUS, URL_UNAVAILABLE
 from tktl.core.config import settings
-from tktl.core.t import AccessKind, ComputeTypeT, InstanceSizeT, ServiceKindT
+from tktl.core.t import AccessKind
 from tktl.core.utils import flatten
 
 
@@ -56,14 +57,16 @@ class RepositoryDeployment(BaseModel, TablePrintableBaseModelMixin):
     status: Optional[str]
     public_docs_url: Optional[str]
 
-    rest_instance_type: Optional[ComputeTypeT]
-    rest_instance_size: Optional[InstanceSizeT]
+    rest_cpu_request: Optional[str]
+    rest_memory_request: Optional[str]
+    rest_gpu_request: Optional[str]
     rest_replicas: Optional[int]
     max_rest_replicas: Optional[int]
-    #
-    arrow_instance_type: Optional[ComputeTypeT]
-    arrow_instance_size: Optional[InstanceSizeT]
+
     arrow_replicas: Optional[int]
+    arrow_cpu_request: Optional[str]
+    arrow_memory_request: Optional[str]
+    arrow_gpu_request: Optional[str]
 
     git_ref: str
     commit_hash: str
@@ -79,30 +82,36 @@ class RepositoryDeployment(BaseModel, TablePrintableBaseModelMixin):
 
     def table_repr(self, subset=None):
         as_dict = self.dict(exclude={"service_type", "endpoints",})
-        as_dict["ID"] = str(as_dict.pop("id"))
-        as_dict[
-            "BRANCH @ COMMIT"
-        ] = f"{as_dict.pop('git_ref')} @ {as_dict.pop('commit_hash')[0:7]}"
-        as_dict["STATUS"] = as_dict.pop("status")
-        as_dict["CREATED AT"] = str(as_dict.pop("created_at"))
-        as_dict["REST DOCS URL"] = _format_http_url(as_dict.pop("public_docs_url"))
-        as_dict["REST INSTANCE"] = self.get_instance(ServiceKindT.REST.value, as_dict)
-        as_dict["ARROW INSTANCE"] = self.get_instance(ServiceKindT.ARROW.value, as_dict)
-        as_dict["ENDPOINTS"] = as_dict.pop("n_endpoints")
-        as_dict[
-            "REST REPLICAS"
-        ] = f"{as_dict.pop('max_rest_replicas')} ({as_dict.pop('rest_replicas')})"
-        as_dict["ARROW REPLICAS"] = as_dict.pop("arrow_replicas")
-        if subset:
-            return {k: v for k, v in as_dict.items() if k in subset}
-        return as_dict
+        repr = {}
+        repr["ID"] = str(as_dict["id"])
+        repr["BRANCH"] = as_dict["git_ref"]
+        repr["COMMIT"] = as_dict["commit_hash"][0:7]
+        repr["STATUS"] = as_dict["status"]
+        repr["ENDPOINTS"] = as_dict["n_endpoints"]
+        repr["CREATED AT"] = str(as_dict["created_at"])
+        repr["REST DOCS URL"] = _format_http_url(as_dict["public_docs_url"])
 
-    @staticmethod
-    def get_instance(kind: ServiceKindT, values: Dict):
-        if values[f"{kind}_instance_type"] is None:
+        repr[
+            "REST REPLICAS"
+        ] = f"{as_dict['max_rest_replicas']} ({as_dict['rest_replicas']})"
+        repr["REST SIZE"] = self.get_requests(ServiceType.REST, as_dict)
+
+        if as_dict["arrow_replicas"] != "0":
+            repr["ARROW REPLICAS"] = as_dict["arrow_replicas"]
+            repr["ARROW SIZE"] = self.get_requests(ServiceType.GRPC, as_dict)
+        if subset:
+            return {k: v for k, v in repr.items() if k in subset}
+        return repr
+
+    def get_requests(self, kind: ServiceType, values: Dict):
+        kind_name = "rest" if kind == ServiceType.REST else "arrow"
+
+        if values[f"{kind_name}_cpu_request"] is None:
             return ""
-        else:
-            return f"{values.pop(f'{kind}_instance_type').value}.{values.pop(f'{kind}_instance_size').value}"
+        requests = f"{values[f'{kind_name}_cpu_request']} {values[f'{kind_name}_memory_request']}"
+        if values[f"{kind_name}_gpu_request"] != "0":
+            return requests + f" {values[f'{kind_name}_gpu_request']} gpus"
+        return requests
 
 
 class Repository(BaseModel, TablePrintableBaseModelMixin):
@@ -163,7 +172,7 @@ def _format_http_url(url: Optional[str], docs: bool = True) -> str:
         return f"http://{url}:8000/{'docs' if docs else ''}"
     if settings.E2E:
         return f"http://{url}/{'docs' if docs else ''}".replace(
-            "local", str(settings.CI_RUNNER_NAME)
+            ".local.taktile.com", "-rest.default.svc.cluster.local", 1
         )
 
     return f"https://{url}/{'docs' if docs else ''}"
@@ -180,7 +189,9 @@ def _format_grpc_url(url: Optional[str]) -> str:
         )
     if settings.E2E:
         return (
-            f"grpc+tcp://{url}:5005".replace("local", str(settings.CI_RUNNER_NAME))
+            f"grpc+tcp://{url}:5005".replace(
+                ".local.taktile.com", "-grpc.default.svc.cluster.local", 1
+            )
             if (url and url != "UNAVAILABLE")
             else "UNAVAILABLE"
         )
