@@ -2,7 +2,7 @@ from collections.abc import Sequence
 from functools import singledispatch
 from typing import Any, Type
 
-import numpy  # type: ignore
+import numpy
 import pandas  # type: ignore
 import pyarrow  # type: ignore
 
@@ -10,7 +10,7 @@ from tktl.core.exceptions import UnsupportedInputTypeException
 from tktl.core.loggers import LOG
 from tktl.core.serializers import arrow
 from tktl.core.serializers.base import ObjectSerializer
-from tktl.core.utils import DelayedLoadingFrame
+from tktl.core.utils import DelayedLoader
 
 
 def deserialize_arrow(model_input: pyarrow.Table):
@@ -60,7 +60,7 @@ def _series(model_input):
     return _do_serialize_with_fallback(arrow.SeriesSerializer, model_input=model_input)
 
 
-@serialize_arrow.register(DelayedLoadingFrame)
+@serialize_arrow.register(DelayedLoader)
 def _delayed_loaded_frame(model_input):
     return model_input
 
@@ -72,6 +72,6 @@ def _do_serialize_with_fallback(
         return serializer_cls.serialize(value=model_input)
     except UnsupportedInputTypeException:
         LOG.warning(
-            "Invalid input supported, will use binary representation for object"
+            "Invalid serialization value, will use binary representation for object"
         )
     return arrow.BinarySerializer.serialize(model_input)
