@@ -1,6 +1,12 @@
 from tktl.core import ExtendedEnum
 
 
+class TemplateT(str, ExtendedEnum):
+    REPAYMENT = "repayment"
+    BARE = "bare"
+    PRECOMPUTED = "precomputed"
+
+
 class UserRepoConfigFileNameT(str, ExtendedEnum):
     YAML = "tktl.yaml"
     YML = "tktl.yml"
@@ -102,3 +108,10 @@ class AccessKind(str, ExtendedEnum):
     # see also corresponding AccessKind on t-api
     OWNER = "owner"
     VIEWER = "viewer"
+
+
+class LazifyType(str, ExtendedEnum):
+    """Type of lazification to be performed"""
+
+    SHAP = "Shap"
+    FIRST_VALID = "FirstValid"
