@@ -4,10 +4,7 @@ from typing import Dict, Union
 
 from pydantic import ValidationError
 
-from tktl.core.exceptions.exceptions import (
-    NoContentsFoundException,
-    UserRepoValidationException,
-)
+from tktl.core.exceptions import NoContentsFoundException, UserRepoValidationException
 from tktl.core.schemas.project import ProjectValidationOutput
 
 
@@ -40,7 +37,7 @@ Debug Output
 
 class ConfigFileValidationFailure(ValidationOutputBase):
     title: str = """Invalid Config File ❌"""
-    summary: str = """We've identified erros in your configuration file. See below for details. Pushes will not succeed or result in new builds"""
+    summary: str = """We've identified erros in your configuration file (tktl.yaml). See below for details. Pushes will not succeed or result in new builds"""
     text = """"""
 
     @classmethod
@@ -62,9 +59,7 @@ class ProjectValidationFailure(ValidationOutputBase):
     @classmethod
     def format_step_results(
         cls,
-        validation_errors: Union[
-            UserRepoValidationException, NoContentsFoundException
-        ] = None,
+        validation_errors: Union[UserRepoValidationException, NoContentsFoundException],
     ):
         debug_output = f"""
 Missing files in repository: {' '.join(validation_errors.missing_files) if
