@@ -1,20 +1,17 @@
 import os
-from typing import Optional, Tuple, Union
+from typing import List, Optional, Tuple, Union
 
 from pydantic import ValidationError
+from taktile_types.schemas.repository.config_yaml import TaktileYAMLConfig
 from yaml import safe_load
 
-from tktl.core.exceptions.exceptions import (
-    NoContentsFoundException,
-    UserRepoValidationException,
-)
+from tktl.core.exceptions import NoContentsFoundException, UserRepoValidationException
 from tktl.core.schemas.project import (
     ProjectContentMultiItemT,
     ProjectContentT,
     ProjectDirectory,
     ProjectFile,
     ProjectFileWithContent,
-    TktlYamlConfigSchema,
 )
 from tktl.core.t import (
     RequiredUserProjectPathsT,
@@ -24,7 +21,7 @@ from tktl.core.t import (
 
 
 def get_user_repo_contents(path: str) -> Optional[ProjectContentT]:
-    contents = []
+    contents: List[Union[ProjectFile, ProjectDirectory]] = []
     files = [os.path.join(path, f) for f in os.listdir(path)]
     for item in files:
         if os.path.isfile(item):
@@ -36,7 +33,7 @@ def get_user_repo_contents(path: str) -> Optional[ProjectContentT]:
 
 def validate_project_contents(
     path: str,
-) -> Tuple[TktlYamlConfigSchema, ProjectContentMultiItemT]:
+) -> Tuple[TaktileYAMLConfig, ProjectContentMultiItemT]:
     contents = get_user_repo_contents(path=path)
     config_found = False
     config_file = None
@@ -51,15 +48,15 @@ def validate_project_contents(
         )
 
     for file in contents:
-        if file.type == UserProjectFileT.FILE.value:
-            if file.name in UserRepoConfigFileNameT.set():
+        if file.type == UserProjectFileT.FILE.value:  # type: ignore
+            if file.name in UserRepoConfigFileNameT.set():  # type: ignore
                 config_found = True
                 config_file = file
-            elif file.name in required_files:
-                required_files.remove(file.name)
-        elif file.type == UserProjectFileT.DIRECTORY.value:
-            if file.name in required_dirs:
-                required_dirs.remove(file.name)
+            elif file.name in required_files:  # type: ignore
+                required_files.remove(file.name)  # type: ignore
+        elif file.type == UserProjectFileT.DIRECTORY.value:  # type: ignore
+            if file.name in required_dirs:  # type: ignore # type: ignore
+                required_dirs.remove(file.name)  # type: ignore
 
     if not config_found or required_dirs or required_files:
         raise UserRepoValidationException(
@@ -67,13 +64,13 @@ def validate_project_contents(
             missing_directories=list(required_dirs),
             missing_config=not config_found,
         )
-    config_file_with_content = decode_file_content(config_file)
-    return config_file_with_content, contents
+    config_file_with_content = decode_file_content(config_file)  # type: ignore
+    return config_file_with_content, contents  # type: ignore
 
 
 def decode_file_content(
     file_with_content: ProjectFileWithContent,
-) -> Union[TktlYamlConfigSchema, ValidationError]:
+) -> Union[TaktileYAMLConfig, ValidationError]:
     with open(file_with_content.path, "r") as yml:
         as_dict = safe_load(yml)
-    return TktlYamlConfigSchema(**as_dict)
+    return TaktileYAMLConfig(**as_dict)
