@@ -1,11 +1,10 @@
+import pathlib
 import typing as t
 
-import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
-from pydantic import BaseModel
-
-from tktl.core.future.t import EndpointKinds, ProfileKinds
+from taktile_types.enums.endpoint import EndpointKinds, ProfileKinds
 
+from .abc import XType, YType
 from .arrow import ArrowEndpoint
 
 
@@ -30,13 +29,13 @@ class ProfiledEndpoint(ArrowEndpoint):
 
     @staticmethod
     def supported(
-        *,
-        X: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
-        y: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
-        profile: t.Optional[str] = None,
+        *, X: XType = None, y: YType = None, profile: t.Optional[str] = None,
     ) -> bool:
-        return (
-            profile in ProfileKinds.set()
-            and isinstance(X, pd.DataFrame)
-            and isinstance(y, pd.Series)
-        )
+
+        if profile not in ProfileKinds.set():
+            return False
+
+        strict = isinstance(X, pd.DataFrame) and isinstance(y, pd.Series)
+        lazy = isinstance(X, pathlib.Path) and isinstance(y, pathlib.Path)
+
+        return strict or lazy
