@@ -1,7 +1,7 @@
 import typing as t
 from functools import singledispatch
 
-import numpy as np
+import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
 
 from tktl.future.registration.exceptions import SerializationError
@@ -42,9 +42,9 @@ def _serialize_dataframe(value: pd.DataFrame):
 
 @singledispatch
 def deserialize(
-    sample: t.Union[np.ndarray, pd.Series, pd.DataFrame], *, value: JSONStructure
+    sample: t.Union[np.ndarray, pd.Series, pd.DataFrame], *, value: JSONStructure,
 ):
-    raise SerializationError(f"Can't serialize value of type {type(sample)}")
+    raise SerializationError(f"Can't deserialize value of type {type(sample)}")
 
 
 @deserialize.register
